<?php

/**
 * The admin-specific functionality of the plugin.
 *
 * @link       https://themesawesome.com/
 * @since      1.0.0
 *
 * @package    Awetube
 * @subpackage Awetube/admin
 */

/**
 * The admin-specific functionality of the plugin.
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the admin-specific stylesheet and JavaScript.
 *
 * @package    Awetube
 * @subpackage Awetube/admin
 * @author     Themes Awesome <admin@themesawesome.com>
 */
class Awetube_Admin {

	/**
	 * The ID of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $plugin_name    The ID of this plugin.
	 */
	private $plugin_name;

	/**
	 * The version of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $version    The current version of this plugin.
	 */
	private $version;

	/**
	 * Initialize the class and set its properties.
	 *
	 * @since    1.0.0
	 * @param      string    $plugin_name       The name of this plugin.
	 * @param      string    $version    The version of this plugin.
	 */
	public function __construct( $plugin_name, $version ) {

		$this->plugin_name = $plugin_name;
		$this->version = $version;

		if(!class_exists('Awetube_Pro')) {
			add_action('admin_menu', array( $this, 'awetubeAddPluginAdminMenu' ), 9);
		}
	}

	/**
	 * Register the stylesheets for the admin area.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_styles() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Awetube_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Awetube_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */

		wp_enqueue_style( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'css/awetube-admin.css', array(), $this->version, 'all' );

	}

	/**
	 * Register the JavaScript for the admin area.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_scripts() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Awetube_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Awetube_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */

		wp_enqueue_script( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'js/awetube-admin.js', array( 'jquery' ), $this->version, false );

	}

	public function awetubeAddPluginAdminMenu() {
		add_submenu_page( 'edit.php?post_type=awetube-video', 'Get Pro Version', 'Get Pro Version', 'administrator', $this->plugin_name.'-settings', array( $this, 'awetubeDisplayPluginAdminSettings' ));
	}

	public function awetubeDisplayPluginAdminSettings() {
		require_once 'partials/'.$this->plugin_name.'-admin-display.php';
	}

}
